@@ -1,13 +1,11 @@
 package Test::Class::Moose::Config;
-{
-  $Test::Class::Moose::Config::VERSION = '0.42';
-}
-
+$Test::Class::Moose::Config::VERSION = '0.43';
 # ABSTRACT: Configuration information for Test::Class::Moose
 
 use 5.10.0;
 use Moose;
 use Moose::Util::TypeConstraints;
+use TAP::Formatter::Color;
 use namespace::autoclean;
 
 subtype 'ArrayRefOfStrings', as 'Maybe[ArrayRef[Str]]';
@@ -15,9 +13,9 @@ subtype 'ArrayRefOfStrings', as 'Maybe[ArrayRef[Str]]';
 coerce 'ArrayRefOfStrings', from 'Str', via { defined($_) ? [$_] : undef };
 
 has 'show_timing' => (
-    is  => 'ro',
-    isa => 'Bool',
-    lazy => 1,
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
     default => sub {
         if ( $_[0]->use_environment and $ENV{HARNESS_IS_VERBOSE} ) {
             return 1;
@@ -35,9 +33,9 @@ has 'builder' => (
 );
 
 has 'statistics' => (
-    is  => 'ro',
-    isa => 'Bool',
-    lazy => 1,
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
     default => sub {
         if ( $_[0]->use_environment and $ENV{HARNESS_IS_VERBOSE} ) {
             return 1;
@@ -104,6 +102,16 @@ has '_current_schedule' => (
     predicate => '_has_schedule',
 );
 
+has '_color' => (
+    is         => 'rw',
+    isa        => 'TAP::Formatter::Color',
+    lazy_build => 1,
+);
+
+sub _build__color {
+    return TAP::Formatter::Color->new;
+}
+
 sub args {
     my $self = shift;
 
@@ -113,6 +121,11 @@ sub args {
     };
 }
 
+sub running_in_parallel {
+    my $self = shift;
+    return $self->jobs > 1 && $self->_has_schedule;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -127,7 +140,7 @@ Test::Class::Moose::Config - Configuration information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -217,6 +230,10 @@ Default is 1.
 
 Only used by C<Test::Class::Moose::Role::Parallel>.
 
+=head2 C<running_in_parallel>
+
+B<EXPERIMENTAL>: Returns true if it appears that we are running in parallel.
+
 =head1 METHODS
 
 =head2 C<args>
